# Changelog

## [Unreleased]

## [0.0.14] - 2021-03-18
* improved StackOverflow
* added Disqus API and Yandex.O

## [0.0.13] - 2021-03-14
* added Gravatar hash extractors
* improved Facebook parsing
* fixed tests

## [0.0.12] - 2021-02-22
* updated requirements

## [0.0.11] - 2021-02-18
* added Linktree, Spotify
* added Twitch, Launchpad
* added Last.fm, Ask.fm
* improved Steam, Habrahabr
* fixed tests

## [0.0.10] - 2021-02-15
* updated setup requirements
* improved Twitter extractor

## [0.0.9] - 2021-02-05
* added Yandex.Music API, 1x.com
* improved errors catching

## [0.0.8] - 2021-02-03
* added Yandex.Messenger

## [0.0.7] - 2021-01-31
* added Tumblr (default theme) and Yandex.Market

## [0.0.6] - 2021-01-31
* updated Yandex services extractors (again)

## [0.0.5] - 2021-01-31
* updated Yandex services extractors

## [0.0.4] - 2021-01-16
* actualized Vimeo and VK

## [0.0.3] - 2021-01-15
* actualized Twitter
